@@ -1,10 +1,3 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
-"""
-Created on Wed Dec 30 11:29:36 2020
-
-@author: jamesdoucette
-"""
 class ListNode:
     def __init__(self, val, next_node):
         self.val=val
